@@ -64,7 +64,7 @@ Rcpp::List threshold_detection_impl(
   int end = 0;
   std::vector<Audio_Event> audio_events;
 
-  int step = fft.size * (1 - FFT_overlap);
+  int step = fft.fft_size * (1 - FFT_overlap);
 
   std::vector<size_t> to_rm;
 
